@@ -1,7 +1,7 @@
 __name__ = "orbis_eval"
-__version__ = "2.3.0rc4"
+__version__ = "2.3.3"
 __author__ = "fabod, rogerwaldvogel"
-__year__ = "2020"
+__year__ = "2021"
 __description__ = "An Extendable Evaluation Pipeline for Named Entity Drill-Down Analysis"
 __license__ = "GPL2"
 __min_python_version__ = "3.6"
@@ -22,9 +22,11 @@ __plugins__ = [
     "orbis_plugin_aggregation_aida",
     "orbis_plugin_aggregation_babelfly",
     "orbis_plugin_aggregation_spotlight",
+    "orbis_plugin_aggregation_weblyzard_harvest",
     "orbis_plugin_evaluation_binary_classification_evaluation",
     "orbis_plugin_metrics_binary_classification_metrics",
     "orbis_plugin_scoring_nel_scorer",
+    "orbis_plugin_scoring_wl_harvest_scorer",
     "orbis_plugin_storage_cache_webservice_results",
     "orbis_plugin_storage_csv_result_list",
     "orbis_plugin_storage_html_pages"
